function [mat,workdata] = create_mat(input)

    cd('../subroutines')
    tStart = tic;

    % Parameters
    sample     = input.sample;
    h          = input.h;
    mod        = input.mod;
    datafolder = input.datafolder;
    firmsize   = input.firmsize;
    savemat    = input.savemat;
    savewdata  = input.savewdata;
    demean     = input.demean;
    if sample == 1
        datafolder = strcat(datafolder,'sample/');
    end
    
    % Report
    fprintf('********************************************************* \n')
    fprintf('Report date    = %s \n', datestr(now))
    fprintf('Future wages   = %d \n', h)
    fprintf('Model          = %d \n', mod)
    fprintf('Firm size lim  = %d \n', firmsize)
    fprintf('Demean y       = %d \n', demean)
    fprintf('Save workdata? = %d \n', savewdata)
    fprintf('Save mat?      = %d \n', savemat)
    fprintf('********************************************************* \n')

    % Data Setup
    fsval = num2str(firmsize);
    hval  = num2str(h);
    rawdatafile = strcat(datafolder,'veneto_fs',fsval,'_w',hval,'.txt');
    rawdata0 = importdata(rawdatafile,',',1);           
    
    % Get id for the largest connected set
    rawdata = rawdata0.data;
    idw = rawdata(:,2);
    idt = rawdata(:,3);
    idf = rawdata(:,4);
    ido = rawdata(:,5);
    idp = findgroups(idf,ido,idt);
    idn = rawdata(:,end);
    lagidf    = createlag(idw,idf); 
    data_temp = [idn idw idf lagidf idp];
    
    fprintf('After largest connected set ... \n')
    ite = 99;
    num = 0;
    while ite > 1 
        num = num + 1;
        [idn,~,~] = connected_set(idn,idw,idf,lagidf);
        [idn,idw,idf,lagidf,ite] = multiworker(idn,data_temp);
    end
    fprintf('... total iterations = %d \n', num)
    
    idn_orig = rawdata(:,end);
    sel=ismember(idn_orig,idn); %largest connected set
    workdata = NaN(sum(sel),size(rawdata,2));
    for i = 1:1:size(rawdata,2)
        temp = rawdata(:,i);
        workdata(:,i) = temp(sel);
    end
    n = size(workdata,1);
    N = size(rawdata,1);
    fprintf('Number of obs = %d, Fraction %3.2f remained \n', n, n/N)
   
    % Relabel IDs (important for creating sparse dummies)
    for i = 2:6 %(!)
        id = workdata(:,i);
        [~,~,nid]=unique(id);
        workdata(:,i) = nid;
    end
    if savewdata == 1
        save(strcat(datafolder,'workdata_f',fsval,'w',hval),'workdata','-v7.3')
    end
    
    % Load variables from cleaned data
    y   = workdata(:,1);
    idw = workdata(:,2);
    idt = workdata(:,3);
    idf = workdata(:,4);
    ido = workdata(:,5);   
    ids = workdata(:,6);
    sW = length(unique(idw));
    sF = length(unique(idf));
    fprintf('Number of workers = %d \n', sW)
    fprintf('Number of firms   = %d \n', sF)
    
    % Get X matrix
    W = sparse(1:length(idw),idw,1);
    F = sparse(1:length(idf),idf,1);
    F = F(:,2:end);
    T = sparse(1:length(idt),idt,1);
    T = T(:,2:end);   
    idft = findgroups(idf,idt);
    FT = sparse(1:length(idft),idft,1);
    FT = FT(1:end,2:end);
    idfo = findgroups(idf,ido);
    FO = sparse(1:length(idfo),idfo,1);
    FO = FO(1:end,2:end);
    idot = findgroups(ido,idt);
    OT = sparse(1:length(idot),idot,1);
    OT = OT(1:end,2:end);
    idsot = findgroups(ids,ido,idt);
    SOT = sparse(1:length(idsot),idsot,1);
    SOT = SOT(1:end,2:end);
    idfot = findgroups(idf,ido,idt);
    FOT = sparse(1:length(idfot),idfot,1);
    FOT = FOT(1:end,2:end);   
    
    age   = workdata(:,11);
    age2  = workdata(:,7);
    ten   = workdata(:,8);
    ten2  = workdata(:,9);
    ten10 = workdata(:,10);
    x = [age age2 ten ten2 ten10];   
    if mod == 1
        D = [FO OT FT];
    elseif mod == 2
        D = [FO SOT FT];  %CDS model
    elseif mod == 3
        D = FOT;          %Portugal model
    end    
    X  = [W x D];
    sX = size(X,2);
    fprintf('X size = %d \n', sX);
    
    % Category
    age    = workdata(:,11);
    female = workdata(:,12);
    tenure = workdata(:,8);
    mover  = workdata(:,13);
    idp    = findgroups(idf,ido,idt);
    psize  = sum(sparse(1:length(idp),idp,1))-1;
    psize  = psize(idp)';
    cat.age = age;
    cat.ten = tenure;
    cat.female = female;
    cat.mover = mover;
    cat.psize = psize;

    % Get C matrix
    fprintf('Getting C ... \n');
    X0size = sX - sW;
    idw_raw = idw;
    idt_raw = idt; 
    idp_raw = findgroups(idf,ido);
    [C] = get_C(idw_raw,idt_raw,idp_raw,W,X0size);
    tEnd = toc(tStart)/60;
    fprintf('Time to get Y, X, C matrices = %5.2f mins \n', tEnd)

    % Demean y
    if demean == 1
        fprintf('Demean y ... \n')
        y = y - mean(y);   
    end

    % Saving Mat for additional matrices    
    fprintf('Saving additional matrices ... \n')
    mat.y  = y;
    mat.X  = X;
    mat.C  = C;
    mat.XX = X'*X;
    mat.Xy = X'*y;
    mat.Cy = C'*y;
    mat.CC = C'*C;
    mat.CX2= C'*X + X'*C; 
    
    mat.F = F;
    mat.W = W;
    mat.FT = FT;
    mat.FO = FO;
    mat.OT = OT;
    mat.FOT = FOT;
    mat.cat = cat;
    if savemat == 1
        mval = num2str(mod);
        save(strcat(datafolder,'mat_f',fsval,'w',hval,'m',mval), ...
            '-struct','mat','-v7.3')
    end
    
    tEnd = toc(tStart)/60;
    fprintf('Time to get all matrices = %5.2f mins \n', tEnd)
    cd('../main_progs')
    
end    