clear
set more off
set type double
set logtype text
graph drop _all

* Some graph options
set scheme s2color
grstyle init
grstyle color background white
grstyle linestyle legend none

glo data	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/data"
glo orig	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/orig"
glo log		"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/log"
glo graph	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Graphs"
glo table	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/table"

capture log close
log using "$log/ContTreat_DataPrep.txt", replace

* Change this if you want to work with sample or full data
local data=0
if `data'==1 local s "sample"
if `data'==0 local s "raw"

use "$data/`s'_veneto_all", clear
drop yr*
format matr_az %12.0f

* merge ALPHA and PHI into the data
merge m:1 cod_pgr matr_az using "$data/alpha_phi"
keep if _merge == 3                // fully merged
drop _merge                        
rename (alpha1 phi1) (alpha psi)   // use reghdfe estimation

********************************************************************************
* Finding the movers
********************************************************************************

* Identify movers
xtset cod_pgr anno
gen _mover=1 if cod_pgr==L.cod_pgr & matr_az!=L.matr_az
recode _mover (.=0)

/* Do not consider movers that do not stay in the destination firm for at least 3 years 
	after the move (it takes some time to pass knowledge) */
gen _todrop=1 if (_mover==1 & L._mover==1) | (_mover==1 & L2._mover==1) | (_mover==1 & L3._mover==1)
bys cod_pgr: egen todrop=mean(_todrop)
gen mover=_mover
replace mover=0 if todrop==1
drop todrop _todrop

* Further check: drop spells that are less than 4 years
bys cod_pgr (anno): gen aux=sum(mover)
bys cod_pgr aux (anno): gen spell_length=_N 
drop if spell_length<4

* Age, age classes & occupation
gen cletad=1*(age>=16 & age<35)+2*(age>=35 & age<55)+3*(age>=55)
tab cletad, gen(cletad_)
gen blue=work_type=="Blue-collar"

* Generate variable with alpha of nonmovers
gen n=1
bysort matr_az anno: egen num_emp=sum(n)
bysort matr_az anno: egen totalpha = sum(alpha)
gen avg_alpha_others = (totalpha - alpha)/(num_emp-1)
drop if avg_alpha_others==.

* Generate variable with wage/alpha of nonmovers
gen avg_wage_nonmover=wwage if _mover!=1
gen avg_alpha_nonmover=alpha if _mover!=1

* Alpha of movers
gen alpha_mover=alpha if _mover==1

tab mover  // 716,675 movers
tempfile movers
save "`movers'"

* Keep only ID for later use
keep mover cod_pgr matr_az anno
keep if mover == 1
drop mover
count 
save "$data/movers_id", replace




********************************************************************************
* Collapse and select firms
********************************************************************************
use "`movers'", clear

* Collapse at the firm-year level
collapse (mean) avg_wage_nonmover avg_alpha_nonmover alpha_mover wwage blue age cletad_* female alpha psi ///
	(sum) mover n, by(matr_az anno)
sort matr_az anno
format matr_az %12.0f
drop if missing(avg_wage_nonmover)

* Firm-level panel
xtset matr_az anno

* Generate treatment variable: firm which has at least a job mover in year t
* and didn't have any in year (t-4, t-3, t-2, ..., t+3) 
gen treat=1 if mover>0 & L.mover==0 & L2.mover==0 & L3.mover==0 & L4.mover==0 & F.mover==0 & F2.mover==0 & F3.mover==0 
gen yeartreat_=anno if treat==1
bys matr_az (anno): carryforward yeartreat_, replace
gsort matr_az -anno
by matr_az: carryforward yeartreat_, replace

* Keep only firms with movers
keep if yeartreat!=.
drop treat

* Time-to-event indicators
sort matr_az anno
gen k=anno-yeartreat_
keep if (k>=-4 & k<=3) 

* NOTE: there are some firms for which pre-event dummies coincide with post-event
* dummies of previous event (e.g. firm that hires a worker in year t, pre-event
* dummies t-2 and t-1 coincide with t+4 and t+5 of hiring happened before):
* I keep only first episode and drop the second
* Sum event dummies (if correct sum is 12)
bys matr_az: egen aux=sum(k)
bys matr_az (anno): gen counter=_n
drop if counter>8
drop aux counter

* Number of movers in year t=0
foreach i in mover alpha_mover {
	gen `i't0_=`i' if k==0
	bys matr_az (yeartreat_) : egen `i't0=mean(`i't0_)
	drop `i't0_
}

* Drop also firms with more than 2 movers
drop if movert0>2
drop movert0 mover

* Some tabulates
tab yeartreat


********************************************************************************
*  Additional variables for matching 
********************************************************************************

* Firm-level info
merge m:1 matr_az using "$orig/azien", keep(1 3) keepusing(cod_fis ateco91 prov data_cost) nogen

tostring data_cost, replace
gen yearcost=substr(data_cost,1,4)
destring yearcost, replace
gen firm_age=anno-yearcost

gen sector_str = substr(ateco91, 1, 1)
replace sector_str = "X" if sector_str == "A" | sector_str == "B" | ///
                            sector_str == "C" | sector_str == "E" | ///
							sector_str == "L"
egen sector=group(sector_str)
xi i.prov i.sector i.anno, noomit
gen lnwwage = ln(wwage)
gen lnfirmsize = ln(n)
gen lnfirmage = ln(firm_age)
gen lnage = ln(age)

* Wage growth
xtset matr_az anno
gen f1wwage = f1.wwage
gen l1wwage = l1.wwage
gen wagegrowth = (l1wwage - wwage)/wwage

tempfile firms	 
save "`firms'", replace

********************************************************************************
* Prepare data for Worker-level analysis
********************************************************************************

use "$data/raw_veneto_all", clear 
drop yr* young-t

merge m:1 matr_az anno using "`firms'"
keep if _merge == 3
drop _merge 

merge 1:1 cod_pgr matr_az anno using "$data/movers_id"
drop if _merge == 2
gen mover = 1 if _merge == 3
count if mover == 1
distinct matr_az    // checked: same
drop _merge 

* Some tabulations
tab k

* Additional variables
cap drop t
gen t=k+5
label define tlab 1 "-4" 2 "-3" 3 "-2" 4 "-1" 5 "0" 6 "1" 7 "2" 8 "3", replace
label values t tlab

save "$data/cont_treat_for_regression", replace



log close
