clear
set more off
set type double
set logtype text
graph drop _all

* Some graph options
set scheme s2color
grstyle init
grstyle color background white
grstyle linestyle legend none
grstyle set color edkblue cranberry orange green gray
grstyle set symbol
grstyle set lpattern

glo data	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/data"
glo log		"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/log"
glo graph	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Graphs"
glo table	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Tables"

capture log close
log using "$log/Descriptives.txt", replace

********************************************************************************
* Descriptives
********************************************************************************

* Change this if you want to work with sample or full data
local sample=0
if `sample'==1 local s "sample"
if `sample'==0 local s "raw"

use "$data/`s'_veneto_all", clear
drop yr*
format matr_az %12.0f

* merge ALPHA and PHI into the data
merge m:1 cod_pgr matr_az using "$data/alpha_phi"
keep if _merge==3
drop _merge


* Descriptive statistics
egen occup=group(work_type)
egen peerid=group(matr_az occup)
egen peersize=count(cod_pgr), by(matr_az occup anno)
gen blue	= work_type=="Blue-collar"
gen white	= work_type=="White-collar"
gen manager	= work_type=="Manager"
gen indet	= contract_type=="Ordinary"
gen det		= (contract_type=="Fixed-term" | contract_type=="Seasonal")
gen manuf	= secname=="Manufacture"
gen service	= secname=="Services"
gen constr	= secname=="Construction"
gen domestic= secname=="DomesticWork"
gen finance	= secname=="Finance"
gen health	= secname=="Health"
gen transp	= secname=="Transports"
gen whole	= secname=="Wholesale"
gen hotel	= secname=="Hotel"
gen other	= (secname=="Agriculture" | secname=="PublicAdmin" | secname=="Electricity")

* Movers
bysort cod_pgr (anno): gen mover  = matr_az[1]  != matr_az[_N]
bysort cod_pgr (anno): gen ymover = matr_az[_n] != matr_az[_n-1]
egen firmmover = sum(ymover), by(matr_az anno)

label variable tot_earnings "Annual earnings"
label variable wwage "Weekly wage"
label variable age "Age"
label variable weeks "Weeks worked"
label variable blue "Blue-collar"
label variable white "White-collar"
label variable manager "Executive"
label variable indet "Open-ended contract"
label variable det "Temporary contract"
label variable female "Woman"
label variable ten "Tenure"
label variable firmsize "Firm size"
label variable peersize "Peer group size"
label variable manuf "Manufacturing"
label variable service "Services"
label variable constr "Construction"
label variable domestic "Domestic work"
label variable finance "Finance"
label variable health "Health"
label variable transp "Transports"
label variable whole "Wholesale"
label variable hotel "Accomodation"
label variable other "Other"
label variable mover "Mover"
label variable firmmover "Movers per firm"

glo covs tot_earnings wwage weeks age ten firmsize firmmover peersize mover female blue indet manuf
foreach var in $covs {
	global lbe_`var' : variable label `var'
	qui sum `var', detail
	local mean_`var' 	: di %6.2f r(mean)
	local sd_`var' 		: di %6.2f r(sd)
	local median_`var' 	: di %6.0f r(p50)
}

* Firm size
preserve
	collapse firmsize firmmover, by(matr_az anno)
	foreach var in firmsize firmmover {
		qui sum `var', d
		local mean_`var' 	: di %6.0f r(mean)
		local sd_`var' 		: di %6.0f r(sd)
		local median_`var' 	: di %6.0f r(p50)
	}
restore

* Peer groups size
preserve
	collapse peersize, by(peerid anno)
	qui sum peersize, d
	local mean_peersize		: di %6.0f r(mean)
	local sd_peersize 		: di %6.0f r(sd)
	local median_peersize 	: di %6.0f r(p50)
restore

count
local obs : disp %12.0fc r(N)
distinct cod_pgr
local workers : disp %12.0fc r(ndistinct)
distinct matr_az
local firms : disp %12.0fc r(ndistinct)

texdoc init $table/Descriptives.tex, replace force

	tex \begin{tabu}{lX[c]X[c]X[c]} \toprule \toprule 
	tex & (1) & (2) & (3) \\
	tex & Mean & S.D. & Median \\
	tex \midrule 
	foreach var in $covs {
		if "`var'"=="tot_earnings"|"`var'"=="wwage"|"`var'"=="weeks"|"`var'"=="age"|"`var'"=="ten"|"`var'"=="firmsize"|"`var'"=="firmmover"|"`var'"=="peersize" {
			tex ${lbe_`var'} & `mean_`var'' & `sd_`var'' & `median_`var'' \\
		}
		else {
			tex ${lbe_`var'} & `mean_`var'' & `sd_`var'' &  \\
		}
		if "`var'"=="ten"|"`var'"=="peersize"|"`var'"=="det" {
			tex \addlinespace
		}
	}
	tex \midrule
	tex Person-year observations & \multicolumn{3}{c}{`obs'} \\
	tex Number of workers & \multicolumn{3}{c}{`workers'} \\
	tex Number of firms & \multicolumn{3}{c}{`firms'} \\
	tex \bottomrule \bottomrule
	tex \end{tabu}

texdoc close


********************************************************************************
* Correlations
********************************************************************************
use /Users/salvatorelattanzio/Dropbox/Research/_Coworker/Estimates/temp_data/temp_veneto_f0.dta, clear

* Movers
bysort cod_pgr (anno): gen mover = matr_az[_n] != matr_az[_n-1]

* Delta peer effects
bys cod_pgr (anno): gen deltapm=pm[_n]-pm[_n-1]
gen deltapm_mover  = deltapm if mover == 1
gen deltapm_stayer = deltapm if mover == 0

two (hist deltapm if mover==1, fcolor(midblue) lcolor(midblue)) ///
	(hist deltapm if mover==0, fcolor(none) lcolor(black)) if inrange(deltapm,-0.3,0.3), ///
	legend(order(1 "Mover" 2 "Stayer")) ylabel(, angle(horizontal) format(%6.0f)) ///
	xlabel(-.3(.1).3) xtitle("Change in peer quality between consecutive years")
graph export ${graph}/DeltaPeerEffectDensity.pdf, replace

label variable lrw 				"log weekly wages"
label variable fe 				"worker fixed effect"
label variable pm 				"peer fixed effect"
label variable otfe 			"occupation-time fixed effect"
label variable ojfe 			"firm-occupation fixed effect"
label variable ftfe 			"firm-time fixed effect"
label variable deltapm 			"change of peer fixed effect between $ t $ and $ t-1 $"
label variable deltapm_mover 	"change of peer fixed effect between $ t $ and $ t-1 $ for movers"
label variable deltapm_stayer 	"change of peer fixed effect between $ t $ and $ t-1 $ for stayers"

* Store standard deviations
foreach var in lrw fe pm otfe ojfe ftfe deltapm deltapm_mover deltapm_stayer {
	local  lbe_`var' : variable label `var'
	global lbe_`var' "Standard deviation `lbe_`var''"
	qui sum `var'
	global sd_`var' : di %4.3f r(sd)
}

* Store correlations
foreach var in pm ftfe ojfe {
	corr fe `var'
	global corr_`var' : di %4.3f r(rho)
	local  lbe_corr_`var' : variable label `var'
	global lbe_corr_`var' "Correlation worker fixed effect/`lbe_corr_`var''"
}

texdoc init $table/Correlations.tex, replace force

	tex \begin{tabu}{lX[c]} \toprule \toprule 
	tex Statistic & Value \\
	tex \midrule
	foreach var in lrw fe pm otfe ojfe ftfe deltapm deltapm_mover deltapm_stayer {
		tex ${lbe_`var'} & ${sd_`var'} \\
	}
	foreach var in pm ftfe ojfe {
		tex ${lbe_corr_`var'} & ${corr_`var'} \\
	}
	tex \bottomrule \bottomrule
	tex \end{tabu}

texdoc close

* Ratio of peer quality change for stayers relative to overall variation of peer effect
qui sum pm
local sd1=r(sd)
qui sum deltapm_stayer
local sd2=r(sd)
disp `sd2'/`sd1'

capture log close

