clear
set more off
set type double
set logtype text
graph drop _all

* Some graph options
set scheme s2color
grstyle init
grstyle color background white
grstyle linestyle legend none

glo data	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/data"
glo log		"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/log"
glo graph	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Graphs"
glo table	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Tables"

glo covs tot_earnings wwage weeks age ten female blue indet manuf

capture log close
log using "$log/DescriptivesCompareMovers.txt", replace

********************************************************************************
* Characteristics of movers
********************************************************************************

* Store IDs of movers from different samples
// Hire design
foreach sample in better worse {

use "$data/hire_`sample'_for_regression", replace
keep if mover == 1 & k == 0 & matched == 1
gduplicates drop cod_pgr, force
keep cod_pgr treated
rename treated treated_hire_`sample'
gen mover_hire_`sample' = 1
save "$data/IDs_hire_`sample'.dta", replace

}

// Leave design
foreach sample in better worse {

use "$data/leave_`sample'_for_regression", clear
keep if mover == 1 & k == 0 & matched == 1
gduplicates drop cod_pgr, force
keep cod_pgr treated
rename treated treated_leave_`sample'
gen mover_leave_`sample' = 1
save "$data/IDs_leave_`sample'.dta", replace

}

// Worker design
foreach sample in better worse {

use "$data/`sample'_matched_worker.dta", replace
keep if k == 0 & matched == 1
gduplicates drop cod_pgr, force
keep cod_pgr treated
rename treated treated_worker_`sample'
gen mover_worker_`sample' = 1
save "$data/IDs_worker_`sample'.dta", replace

}


********************************************************************************
* Full data
********************************************************************************
use "$data/raw_veneto_all", clear
drop yr*
format matr_az %12.0f

* merge ALPHA and PHI into the data
merge m:1 cod_pgr matr_az using "$data/alpha_phi"
keep if _merge == 3                // fully merged
drop _merge                        
rename (alpha1 phi1) (alpha psi)   // use reghdfe estimation

* Gen variables for descriptives
gen blue	= work_type=="Blue-collar"
gen indet	= contract_type=="Ordinary"
gen manuf	= secname=="Manufacture"

* Define 3-year lag, which we use for summary stats table later on
xtset cod_pgr anno
foreach var in $covs {
gen l3`var' = L3.`var'
}
	
* Identify movers
gen mover=1 if cod_pgr==L.cod_pgr & matr_az!=L.matr_az
keep if mover == 1
drop mover

* merge movers IDs
merge m:1 cod_pgr using "$data/IDs_hire_better.dta"		, nogen keep(1 3)
merge m:1 cod_pgr using "$data/IDs_hire_worse.dta"		, nogen keep(1 3)
merge m:1 cod_pgr using "$data/IDs_leave_better.dta"	, nogen keep(1 3)
merge m:1 cod_pgr using "$data/IDs_leave_worse.dta"		, nogen keep(1 3)
merge m:1 cod_pgr using "$data/IDs_worker_better.dta"	, nogen keep(1 3)
merge m:1 cod_pgr using "$data/IDs_worker_worse.dta"	, nogen keep(1 3)
recode treated* mover* (.=0)

* aggregate categories
gen mover_hire 		= (mover_hire_better == 1 | mover_hire_worse == 1)
gen mover_leave 	= (mover_leave_better == 1 | mover_leave_worse == 1)
gen mover_worker 	= (mover_worker_better == 1 | mover_worker_worse == 1)
gen mover_other		= (mover_hire == 0 & mover_leave == 0 & mover_worker == 0)
gen mover_all 		= 1

* Keep only vars 3 yrs before move
drop $covs
foreach var in $covs {
rename l3`var' `var'
}
keep cod_pgr anno matr_az mover* $covs

* Descriptive statistics
label variable tot_earnings "Annual earnings"
label variable wwage "Weekly wage"
label variable age "Age"
label variable weeks "Weeks worked"
label variable blue "Blue-collar"
label variable indet "Open-ended contract"
label variable female "Woman"
label variable ten "Tenure"
label variable manuf "Manufacturing"

foreach var in $covs {
	if "`var'" == "tot_earnings" local fmt %6.2fc
	if "`var'" != "tot_earnings" local fmt %3.2f
	global lbe_`var' : variable label `var'
	foreach type in hire leave worker other {
		qui sum `var' if mover_`type'==1
		local mean_`var'_`type' 	: di `fmt' r(mean)
		local sd_`var'_`type' 		: di `fmt' r(sd)
	}
}

foreach type in hire leave worker other {
	count if mover_`type'==1
	local N_`var'_`type' 	: di %9.0fc r(N)
}


texdoc init $table/DescriptivesCompareMovers.tex, replace force

	tex \begin{tabu}{lX[c]X[c]X[c]X[c]} \toprule \toprule 
	tex & (1) & (2) & (3) & (4) \\
	tex & Hire & Leave & Worker & Other \\
	tex \midrule 
	foreach var in $covs {
			tex ${lbe_`var'} & `mean_`var'_hire' & `mean_`var'_leave' & `mean_`var'_worker' & `mean_`var'_other' \\
			tex & (`sd_`var'_hire') & (`sd_`var'_leave') & (`sd_`var'_worker') & (`sd_`var'_other') \\ \addlinespace[.1cm]
	}
	tex \midrule
	tex Number of workers & `N_`var'_hire' & `N_`var'_leave' & `N_`var'_worker' & `N_`var'_other' \\
	tex \bottomrule \bottomrule
	tex \end{tabu}

texdoc close

