clear
set more off
set type double
set logtype text
graph drop _all

* Some graph options
set scheme s2color
grstyle init
grstyle color background white
grstyle linestyle legend none

glo data	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/data"
glo log		"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/log"
glo graph	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Graphs"
glo table	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/table"

capture log close
log using "$log/Leaver_DataPrep_Matching.txt", replace

* Change this if you want to work with sample or full data
local sample=0
if `sample'==1 local s "sample"
if `sample'==0 local s "raw"

use "$data/`s'_veneto_all", clear
drop yr*
format matr_az %12.0f

* merge ALPHA and PHI into the data
merge m:1 cod_pgr matr_az using "$data/alpha_phi"
keep if _merge == 3                // fully merged
drop _merge                        
rename (alpha1 phi1) (alpha psi)   // use reghdfe estimation

********************************************************************************
* Finding the leavers
********************************************************************************

* Identify leavers
xtset cod_pgr anno
gen _leaver=1 if cod_pgr==F.cod_pgr & matr_az!=F.matr_az
recode _leaver (.=0)

/* Do not consider leavers that do not stay in the orignal firm for at least 3 years 
	after the move (it takes some time to pass knowledge) */
gen _todrop=1 if (_leaver==1 & F._leaver==1) | (_leaver==1 & F2._leaver==1) | (_leaver==1 & F3._leaver==1)
bys cod_pgr: egen todrop=mean(_todrop) // This is quite restrictive already
gen leaver=_leaver
bys cod_pgr matr_az (anno): gen N=_N 
replace todrop=1 if N<3 //do not consider leavers that stay in any firm less than 3 years
replace leaver=0 if todrop==1
drop todrop _todrop

* Generate variable with wage/alpha of nonleavers
gen avg_wage_nonleaver=wwage if _leaver!=1
gen avg_alpha_nonleaver=alpha if _leaver!=1

* Categories of mobility based on comparison of own ability with coworkers' ability
gen n=1
bysort matr_az anno: egen num_emp=sum(n)
bysort matr_az anno: egen totalpha = sum(alpha)
gen avg_alpha_others = (totalpha - alpha)/(num_emp-1)
drop if avg_alpha_others==.
sort cod_pgr anno
gen lower=1 if leaver==1 & alpha<=avg_alpha_others-.1
gen upper=1 if leaver==1 & alpha>avg_alpha_others+.1
gen simil=1 if leaver==1 & alpha>avg_alpha_others-.1 & alpha<=avg_alpha_others+.1

* Age and age classes
gen cletad=1*(age>=16 & age<35)+2*(age>=35 & age<55)+3*(age>=55)
tab cletad, gen(cletad_)

* Blue-collar workers
gen blue=work_type=="Blue-collar"

tab leaver  // 716,675 leavers
tempfile movers
save "`movers'"


* Keep only ID for later use
preserve 
keep leaver cod_pgr matr_az anno
keep if leaver == 1
drop leaver
count 
save "$data/movers_id_leaver", replace
restore 


* Collapse at the firm-year level
collapse (mean) avg_wage_nonleaver avg_alpha_nonleaver wwage blue age ///
				cletad_* female alpha psi ///
	      (sum) leaver upper lower simil n, by(matr_az anno)
assert leaver==lower+upper+simil
sort matr_az anno
format matr_az %12.0f
drop if missing(avg_wage_nonleaver)

********************************************************************************
* Collapse in Firms and Select firms
********************************************************************************

* Firm-level panel
xtset matr_az anno

* Generate treatment variable: firm which has at least a job leaver in year t
* and didn't have any in year (t-4, t-3, t-2, ..., t+3) 
gen treat=1 if leaver>0 & L.leaver==0 & L2.leaver==0 & L3.leaver==0 & L4.leaver==0 & F.leaver==0 & F2.leaver==0 & F3.leaver==0 
gen yeartreat_=anno if treat==1   //!
bys matr_az (anno): carryforward yeartreat_, replace
gsort matr_az -anno
by matr_az: carryforward yeartreat_, replace

* Identify control firms among those not treated and who do not have leavers in 
* a time span of 8 years (i.e. from t-4 to t+3)
sort matr_az anno
gen controlgroup_=1 if yeartreat==. & leaver==0 & L.leaver==0 & L2.leaver==0 & L3.leaver==0 & L4.leaver==0 & F.leaver==0 & F2.leaver==0 & F3.leaver==0 
bys matr_az: egen yearplacebo_=min(anno) if controlgroup==1
bys matr_az (anno): carryforward yearplacebo_, replace
gsort matr_az -anno
by matr_az: carryforward yearplacebo_, replace

* Time-to-event indicators
sort matr_az anno
gen k=anno-yeartreat_
gen k2=anno-yearplacebo_ 
keep if (k>=-4 & k<=3) | (k2>=-4 & k2<=3)
replace k=k2 if k==.

* NOTE: there are some firms for which pre-event dummies coincide with post-event
* dummies of previous event (e.g. firm that hires a worker in year t, pre-event
* dummies t-2 and t-1 coincide with t+4 and t+5 of hiring happened before):
* I keep only first episode and drop the second
* Sum event dummies (if correct sum is 12)
bys matr_az: egen aux=sum(k)
bys matr_az (anno): gen counter=_n
drop if counter>8
drop aux counter

* Treatment indicators
gen treated=1 if yeartreat_!=.
replace treated=0 if yearplacebo_!=.
drop treat controlgroup_ k2

* Number of leavers in year t=0
foreach i in leaver upper lower simil {
	gen `i't0_=`i' if k==0
	bys matr_az (yeartreat_) : egen `i't0=mean(`i't0_)
	drop `i't0_
}

* There shouldn't be any leaver for treated==0
tab leavert0 treated
assert leavert0==uppert0+lowert0+similt0

* Unique variable for treatment year (=actual year of mobility for treated firms; placebo year for control firms)
gen yeartreat=yeartreat_
replace yeartreat=yearplacebo_ if treated==0
drop yeartreat_ yearplacebo_

* Drop intersections
drop if uppert0>0 & lowert0>0
drop if uppert0>0 & similt0>0
drop if lowert0>0 & similt0>0

* Drop also firms with more than 2 leavers
drop if leavert0>2


* Identify firms that replace workers (drop firms that change in size over time)
xtset matr_az k
gen deltan=D.n
gen _deltant0=deltan if k==0
bys matr_az (k): egen deltant0=mean(_deltant0)
// Drop firms that change size in the control group
drop if treated==0 & deltant0!=0
// Drop firms that change size in the treatment group (outside of interval -2/+2 employees)
drop if treated==1 & !inrange(deltant0,-2,2)
gen replacew=1
recode replacew (1=0) if deltant0>0
gen addw=1
recode addw (1=0) if deltant0<=0 & treated==1


* Some tabulates
tab yeartreat
tab treated   // 65,968
rename treated moved

* Save dataset
tempfile selectedfirms
save "`selectedfirms'"


********************************************************************************
* Restricted on firms with mobility
********************************************************************************
keep if moved == 1

* Treatment indicators
gen treated=0 if similt0>0
recode treated (.=1) if lowert0>0
recode treated (.=2) if uppert0>0
label define trlab 0 "Similar leaver" 1 "Worse leaver" 2 "Better leaver", replace
label values treated trlab
tab k treated

* Save dataset
tempfile selectedfirms_mobility
save "`selectedfirms_mobility'"


********************************************************************************
*  Prepare additional variables for matching 
********************************************************************************

* Firm-level info
merge m:1 matr_az using "$data/azien", keep(1 3) keepusing(cod_fis ateco91 prov data_cost) nogen

tostring data_cost, replace
gen yearcost=substr(data_cost,1,4)
destring yearcost, replace
gen firm_age=anno-yearcost

gen sector_str = substr(ateco91, 1, 1)
replace sector_str = "X" if sector_str == "A" | sector_str == "B" | ///
                            sector_str == "C" | sector_str == "E" | ///
							sector_str == "L"
egen sector=group(sector_str)
xi i.prov i.sector i.anno, noomit
gen lnwwage = ln(wwage)
gen lnfirmsize = ln(n)
gen lnfirmage = ln(firm_age)
gen lnage = ln(age)


* Balaced-sheet data 
preserve 
use "$data/AIDA_1995_2001", clear
sum
gen cod_fis = Codicefiscale
gen cod_fis_1digit = substr(cod_fis,1,1)
tab cod_fis_1digit  // 0 1 4 8 9
drop cod_fis_1digit
destring cod_fis, replace
gen anno = year
save temp1, replace
restore 

gen cod_fis_1digit = substr(cod_fis,1,1)
gen cod_fis_merge = (cod_fis_1digit == "0" | cod_fis_1digit == "1" |  ///
					 cod_fis_1digit == "4" | cod_fis_1digit == "8" |  ///
					 cod_fis_1digit == "9") 
replace cod_fis	= "" if cod_fis_merge == 0
drop cod_fis_1digit cod_fis_merge
destring cod_fis, replace

merge m:1 cod_fis anno using "temp1.dta", keep(1 3) nogen ///
		  keepusing(ricavi val_added attivo reddito_op reddito_netto ROS ROA)
erase temp1.dta

foreach v of varlist ricavi-ROA {
	gen `v'_md = (`v' == .)
	replace `v' = 1e7-1 if `v' == .
	gen ln_`v' = ln(`v')
}
gen merge_md = ricavi_md
drop ricavi_md-reddito_netto_md
global cov_bs "ricavi val_added merge_md"


* Wage growth
xtset matr_az anno
gen f1wwage = f1.wwage
gen l1wwage = l1.wwage
gen wagegrowth = (l1wwage - wwage)/wwage


preserve 
keep if treated == 0 | treated == 2
gen treat = (treated == 2)
drop treated
tab treat 
save "$data/leave_better_for_matching", replace 
restore 

preserve 
keep if treated == 0 | treated == 1
gen treat = (treated == 1)
drop treated
tab treat 
save "$data/leave_worse_for_matching", replace 
restore 


********************************************************************************
*  Propensity Score Matching
********************************************************************************

local data "better worse"

foreach sample of local data {

use "$data/leave_`sample'_for_matching", clear
rename treat treated

set seed 20200628 // 20200628  
local bs "ricavi val_added attivo reddito_op reddito_netto"
foreach v of local bs {
	gen random_`v' = runiform()*1e5
	replace `v' = random_`v' if merge_md == 1
	drop random_`v'
}

foreach var in wwage {
	gen aux1=`var' if k==-4
	gen aux2=`var' if k==-3
	gen aux3=`var' if k==-2
	local k=4
	forvalues i=1/3 {
		bys matr_az: egen `var'_m`k'=mean(aux`i')
		local k=`k'-1
	}
	drop aux*
}

* Keep only observations at time t-3 and perform matching
keep if k==-3
global covs "wwage_m4 wwage_m3 wwage_m2 alpha psi age female blue n firm_age val_added ricavi"
keep matr_az $covs sector prov treated
xi i.prov i.sector, noomit
*global covs "wwage psi alpha age female blue n firm_age ricavi val_added wagegrowth" /*_Isector* _Iprov**/
*global covs "wwage wagegrowth alpha psi age female blue n firm_age ricavi val_added  attivo reddito_op reddito_netto"


* Propensity score
psmatch2 treated $covs _Isector* _Iprov*, caliper(.001) noreplace neighbor(1)
gen pair = _id if _treated==0 
replace pair = _n1 if _treated==1
bysort pair: egen paircount = count(pair)
gen matched=paircount==2

* Balance test of covariates
local n : list sizeof global(covs)
mat b=J(`n',2,.)
mat s=J(`n',2,.)
local i=1
foreach var in $covs {
	* Standardize dep. var.
	sum `var'
	gen svar=(`var'-r(mean))/r(sd)
	* Unmatched
	reg svar treated, r
	mat b[`i',1]=_b[treated]
	mat s[`i',1]=_se[treated]
	* Matched
	reg svar treated if matched==1, r
	mat b[`i',2]=_b[treated]
	mat s[`i',2]=_se[treated]
	drop svar
	local i=`i'+1
}

* Graph (need Mac Stata)
preserve
	
	drop _all
	svmat b
	svmat s
	rename (b1 b2 s1 s2) (bu bm su sm)
	gen ulu=bu+1.96*su
	gen llu=bu-1.96*su
	gen ulm=bm+1.96*sm
	gen llm=bm-1.96*sm
	gen n=_n
	gen nu=n+.1
	gen nm=n-.1
	keep if n <= 12

	gen varname = _n
	tostring varname, replace
	replace varname = "Weekly wage -4"       if varname == "1"
	replace varname = "Weekly wage -3"       if varname == "2"
	replace varname = "Weekly wage -2"       if varname == "3"
	replace varname = "AKM worker effect" 	 if varname == "4"
	replace varname = "AKM firm effect"   	 if varname == "5"
	replace varname = "Employees' age"    	 if varname == "6"
	replace varname = "Share female"      	 if varname == "7"
	replace varname = "Share blue-collar" 	 if varname == "8"
	replace varname = "Firm size"         	 if varname == "9"
	replace varname = "Firm age"          	 if varname == "10"
	replace varname = "Sales revenue"     	 if varname == "11"
	replace varname = "Value added"       	 if varname == "12"

	labmask n, values(varname)	// * findit labmask
	*save "$data/ControlA", replace
	
	twoway (scatter n bm, ms(none)) (scatter nm bm, ms(D) mc(edkblue)) (scatter nu bu, ms(O) mc(cranberry)) ///
		  (rcap ulm llm nm, hor lc(edkblue) lw(.5)) (rcap ulu llu nu, hor lc(cranberry) lp(dash) lw(.5)), ///
		  xline(0) graphregion(c(white) margin(l+27)) yti("") ///
		  ylabel(1(1)12, valuelabel angle(horizontal) format(%20.0f)) legend(order(3 "Unmatched" 2 "Matched")) ///
		  xti("Standardized coefficient") name(balance_test_mA, replace) 
	graph export "$graph/Leave_BalanceTest_`sample'.pdf", replace	
	
	twoway (scatter n bm, ms(D) xline(0)) (rcap ulm llm n, hor lc(black)), ///
		  graphregion(c(white) margin(l+27)) yti("") ///
		  xscale(r(-0.25 0.2)) xlabel(-0.2(0.1)0.2) ///
		  ylabel(1(1)12, valuelabel angle(horizontal) format(%20.0f)) legend(off) ///
		  xti("Standardized coefficient") name(balance_test_mA, replace) 
	graph export "$graph/Leave_BalanceTestMatched_`sample'.pdf", replace		  	  
			  
	twoway (scatter n bu, ms(D) xline(0)) (rcap ulu llu n, hor lc(black)), ///
		graphregion(c(white) margin(l+27)) ylabel(1(1)12, valuelabel angle(horizontal)) ///
		xti("Standardized coefficient")  legend(off) ///
		xscale(r(-0.25 0.2)) xlabel(-0.2(0.1)0.2) ///
		legend(off) name(balance_test_uA, replace) yti("")
	graph export "$graph/Leave_BalanceTestUnmatched_`sample'.pdf", replace	
	
restore



* Density of pscore in treated and control firms
twoway (kdensity _pscore if treated==1, lc(black) lw(.5)) (kdensity _pscore if treated==0, lc(black) lp(dash) lw(.5)), ///
	legend(order(1 "Treated firms" 2 "Control firms")) yti("Kernel density") xti("Propensity score")
graph export "$graph/Leave_PscoreDensity_`sample'.pdf", replace

	
* Keep only relevant variables for matching and restrict to common support
keep if _support==1
keep matr_az _pscore _weight treated matched

* Some tabulations
tab treated  // matched with 4,057 control groups for better 
             // matched with 4,057 control groups for worse


* Merge back to the original firm-year panel
merge 1:m matr_az using "$data/leave_`sample'_for_matching"  // fully merged
keep matr_az treated _pscore _weight anno k matched
			 		 
tempfile `sample'_matched 		 
save "``sample'_matched'", replace


}


local data  "better worse"  
foreach sample of local data {

********************************************************************************
* Prepare data for Worker-level analysis
********************************************************************************

use "$data/raw_veneto_all", clear 
drop yr* young-t

merge m:1 matr_az anno using "``sample'_matched'"
keep if _merge == 3
drop _merge 

merge 1:1 cod_pgr matr_az anno using "$data/movers_id_leaver"
drop if _merge == 2
gen mover = 1 if _merge == 3
count if mover == 1
distinct matr_az    // checked: same
drop _merge 


* Some tabulations
tab k treated
tab k treated if matched==1

* Additional variables
cap drop t
gen t=k+5
label define tlab 1 "-4" 2 "-3" 3 "-2" 4 "-1" 5 "0" 6 "1" 7 "2" 8 "3", replace
label values t tlab

save "$data/leave_`sample'_for_regression", replace

}

log close
