clear
set more off
set type double
set logtype text
graph drop _all

* Some graph options
set scheme s2color
grstyle init
grstyle color background white
grstyle linestyle legend none

glo data	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/data"
glo orig	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/orig"
glo log		"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/log"
glo graph	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Graphs"
glo table	"/Users/salvatorelattanzio/Dropbox/Research/_Coworker/Event_study/output/table"

capture log close
log using "$log/Leaver_ContTreat_DataPrep.txt", replace

* Change this if you want to work with sample or full data
local sample=0
if `sample'==1 local s "sample"
if `sample'==0 local s "raw"

use "$data/`s'_veneto_all", clear
drop yr*
format matr_az %12.0f

* merge ALPHA and PHI into the data
merge m:1 cod_pgr matr_az using "$data/alpha_phi"
keep if _merge == 3                // fully merged
drop _merge                        
rename (alpha1 phi1) (alpha psi)   // use reghdfe estimation

********************************************************************************
* Finding the leavers
********************************************************************************

* Identify leavers
xtset cod_pgr anno
gen _leaver=1 if cod_pgr==F.cod_pgr & matr_az!=F.matr_az
recode _leaver (.=0)

/* Do not consider leavers that do not stay in the orignal firm for at least 3 years 
	after the move (it takes some time to pass knowledge) */
gen _todrop=1 if (_leaver==1 & F._leaver==1) | (_leaver==1 & F2._leaver==1) | (_leaver==1 & F3._leaver==1)
bys cod_pgr: egen todrop=mean(_todrop) // This is quite restrictive already
gen leaver=_leaver
bys cod_pgr matr_az (anno): gen N=_N 
replace todrop=1 if N<3 //do not consider leavers that stay in any firm less than 3 years
replace leaver=0 if todrop==1
drop todrop _todrop

* Generate variable with wage/alpha of nonleavers
gen avg_wage_nonleaver=wwage if _leaver!=1
gen avg_alpha_nonleaver=alpha if _leaver!=1

* Alpha of movers
gen alpha_leaver=alpha if _leaver==1

* Age and age classes
gen cletad=1*(age>=16 & age<35)+2*(age>=35 & age<55)+3*(age>=55)
tab cletad, gen(cletad_)

* Blue-collar workers
gen blue=work_type=="Blue-collar"

tab leaver  // 716,675 leavers
tempfile movers
save "`movers'"


* Keep only ID for later use
preserve 
keep leaver cod_pgr matr_az anno
keep if leaver == 1
drop leaver
count 
save "$data/movers_id_leaver", replace
restore 


* Collapse at the firm-year level
gen n=1
collapse (mean) avg_wage_nonleaver avg_alpha_nonleaver alpha_leaver wwage blue age ///
				cletad_* female alpha psi ///
	      (sum) leaver n, by(matr_az anno)
sort matr_az anno
format matr_az %12.0f
drop if missing(avg_wage_nonleaver)

********************************************************************************
* Collapse in Firms and Select firms
********************************************************************************

* Firm-level panel
xtset matr_az anno

* Generate treatment variable: firm which has at least a job leaver in year t
* and didn't have any in year (t-4, t-3, t-2, ..., t+3) 
gen treat=1 if leaver>0 & L.leaver==0 & L2.leaver==0 & L3.leaver==0 & L4.leaver==0 & F.leaver==0 & F2.leaver==0 & F3.leaver==0 
gen yeartreat_=anno if treat==1   //!
bys matr_az (anno): carryforward yeartreat_, replace
gsort matr_az -anno
by matr_az: carryforward yeartreat_, replace

* Keep only firms with movers
keep if yeartreat!=.
drop treat

* Time-to-event indicators
sort matr_az anno
gen k=anno-yeartreat_
keep if (k>=-4 & k<=3) 

* NOTE: there are some firms for which pre-event dummies coincide with post-event
* dummies of previous event (e.g. firm that hires a worker in year t, pre-event
* dummies t-2 and t-1 coincide with t+4 and t+5 of hiring happened before):
* I keep only first episode and drop the second
* Sum event dummies (if correct sum is 12)
bys matr_az: egen aux=sum(k)
bys matr_az (anno): gen counter=_n
drop if counter>8
drop aux counter

* Number of leavers in year t=0
foreach i in leaver alpha_leaver {
	gen `i't0_=`i' if k==0
	bys matr_az (yeartreat_) : egen `i't0=mean(`i't0_)
	drop `i't0_
}

* Drop firms with more than 2 leavers
drop if leavert0>2
drop leavert0 leaver

* Some tabulates
tab yeartreat


********************************************************************************
*  Prepare additional variables for matching 
********************************************************************************

* Firm-level info
merge m:1 matr_az using "$orig/azien", keep(1 3) keepusing(cod_fis ateco91 prov data_cost) nogen

tostring data_cost, replace
gen yearcost=substr(data_cost,1,4)
destring yearcost, replace
gen firm_age=anno-yearcost

gen sector_str = substr(ateco91, 1, 1)
replace sector_str = "X" if sector_str == "A" | sector_str == "B" | ///
                            sector_str == "C" | sector_str == "E" | ///
							sector_str == "L"
egen sector=group(sector_str)
xi i.prov i.sector i.anno, noomit
gen lnwwage = ln(wwage)
gen lnfirmsize = ln(n)
gen lnfirmage = ln(firm_age)
gen lnage = ln(age)

* Balaced-sheet data 
preserve 
use "$data/AIDA_1995_2001", clear
sum
gen cod_fis = Codicefiscale
gen cod_fis_1digit = substr(cod_fis,1,1)
tab cod_fis_1digit  // 0 1 4 8 9
drop cod_fis_1digit
destring cod_fis, replace
gen anno = year
save temp1, replace
restore 

gen cod_fis_1digit = substr(cod_fis,1,1)
gen cod_fis_merge = (cod_fis_1digit == "0" | cod_fis_1digit == "1" |  ///
					 cod_fis_1digit == "4" | cod_fis_1digit == "8" |  ///
					 cod_fis_1digit == "9") 
replace cod_fis	= "" if cod_fis_merge == 0
drop cod_fis_1digit cod_fis_merge
destring cod_fis, replace

merge m:1 cod_fis anno using "temp1.dta", keep(1 3) nogen ///
		  keepusing(ricavi val_added attivo reddito_op reddito_netto ROS ROA)
erase temp1.dta

foreach v of varlist ricavi-ROA {
	gen `v'_md = (`v' == .)
	replace `v' = 1e7-1 if `v' == .
	gen ln_`v' = ln(`v')
}
gen merge_md = ricavi_md
drop ricavi_md-reddito_netto_md
global cov_bs "ricavi val_added merge_md"

* Wage growth
xtset matr_az anno
gen f1wwage = f1.wwage
gen l1wwage = l1.wwage
gen wagegrowth = (l1wwage - wwage)/wwage

tempfile firms	 
save "`firms'", replace


********************************************************************************
* Prepare data for Worker-level analysis
********************************************************************************

use "$data/raw_veneto_all", clear 
drop yr* young-t

merge m:1 matr_az anno using "`firms'"
keep if _merge == 3
drop _merge 

merge 1:1 cod_pgr matr_az anno using "$data/movers_id"
drop if _merge == 2
gen mover = 1 if _merge == 3
count if mover == 1
distinct matr_az    // checked: same
drop _merge 

set seed 20200628 // 20200628  
local bs "ricavi val_added attivo reddito_op reddito_netto"
foreach v of local bs {
	gen random_`v' = runiform()*1e5
	replace `v' = random_`v' if merge_md == 1
	drop random_`v'
}

* Some tabulations
tab k 

* Additional variables
cap drop t
gen t=k+5
label define tlab 1 "-4" 2 "-3" 3 "-2" 4 "-1" 5 "0" 6 "1" 7 "2" 8 "3", replace
label values t tlab

save "$data/leave_cont_treat_for_regression", replace



log close
